@@ -9,20 +9,16 @@
 ;; Others:
 ;;   Vijay Lakshminarayanan: support for choosing boxes comment by current buffer mode.
 
-;; This program is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
-;; any later version.
+;; boxes - Command line filter to draw/remove ASCII boxes around text
+;; Copyright (c) 1999-2021 Thomas Jensen and the boxes contributors
 ;;
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
-;;
-;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, you can either send email to this
-;; program's maintainer or write to: The Free Software Foundation,
-;; Inc.; 675 Massachusetts Avenue; Cambridge, MA 02139, USA.
+;; This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
+;; License, version 3, as published by the Free Software Foundation.
+;; This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+;; warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+;; details.
+;; You should have received a copy of the GNU General Public License along with this program.
+;; If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -46,28 +42,26 @@
   "The boxes command.")
 
 (defvar boxes-types-alist
-  (ignore-errors
-   (with-temp-buffer
-     (call-process "boxes" nil t nil "-l")
-     (goto-char (point-min))
-     (let ((retval nil))
-       (while (re-search-forward "^\\([a-zA-Z][a-zA-Z0-9-]+\\)" nil t)
-	 (add-to-list 'retval (cons (match-string 1)
-				    (match-string 1))))
-       retval)))
+  (let ((the-types (process-lines boxes-command "-q" "(all)"))
+        (the-alist (list)))
+    (dolist (el the-types the-alist)
+      (let ((no-alias (replace-regexp-in-string " *\(alias\) *$" "" el)))
+        (add-to-list 'the-alist 
+                     (cons no-alias no-alias)))))
   "Association of types available to the current boxes implementation." )
 (make-variable-buffer-local 'boxes-types-alist)
 
 (defvar boxes-history nil)
 
 ;;;###autoload
-(defvar boxes-known-modes
+(defcustom boxes-known-modes
   '((c-mode . "c-cmt2") (c++-mode . "c-cmt2") (java-mode . "java-cmt")
     (html-mode . "html-cmt") (sh-mode . "pound-cmt") (perl-mode . "pound-cmt")
     (python-mode . "pound-cmt") (ruby-mode . "pound-cmt")
     (emacs-lisp-mode . "lisp-cmt") (lisp-mode . "lisp-cmt"))
-  "The default comment type based on file names.")
-(make-variable-buffer-local 'boxes-known-modes)
+  "The default comment type based on file names."
+:group 'customize
+)
 
 ;;;###autoload
 (defun boxes-set-default-type (mode)
