@@ -2,20 +2,15 @@
  * boxes - Command line filter to draw/remove ASCII boxes around text
  * Copyright (c) 1999-2021 Thomas Jensen and the boxes contributors
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License, version 2, as published
- * by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
+ * License, version 3, as published by the Free Software Foundation.
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
+ * You should have received a copy of the GNU General Public License along with this program.
+ * If not, see <https://www.gnu.org/licenses/>.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
-* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  */
 
 /*
@@ -69,8 +64,8 @@ extern int optind;     /* for getopt() */
  */
 static void usage_short(FILE *st)
 {
-    fprintf(st, "Usage: %s [options] [infile [outfile]]\n", PROJECT);
-    fprintf(st, "Try `%s -h' for more information.\n", PROJECT);
+    bx_fprintf(st, "Usage: %s [options] [infile [outfile]]\n", PROJECT);
+    bx_fprintf(st, "Try `%s -h' for more information.\n", PROJECT);
 }
 
 
@@ -139,10 +134,11 @@ static opt_t *create_new_opt()
  */
 static int alignment(opt_t *result, char *optarg)
 {
-    int errfl = 0;
+    int errfl = 1;
     char *p = optarg;
 
     while (*p) {
+        errfl = 0;
         if (p[1] == '\0' && !strchr("lLcCrR", *p)) {
             errfl = 1;
             break;
@@ -210,7 +206,7 @@ static int alignment(opt_t *result, char *optarg)
     }
 
     if (errfl) {
-        fprintf(stderr, "%s: Illegal text format -- %s\n", PROJECT, optarg);
+        bx_fprintf(stderr, "%s: Illegal text format -- %s\n", PROJECT, optarg);
         return 1;
     }
     return 0;
@@ -226,20 +222,15 @@ static int alignment(opt_t *result, char *optarg)
  */
 static int command_line_design(opt_t *result, char *optarg)
 {
+    if (strlen(optarg) == 0) {
+        bx_fprintf(stderr, "%s: empty command line design definition\n", PROJECT);
+        return 2;
+    }
     result->cld = (char *) strdup(optarg);
     if (result->cld == NULL) {
         perror(PROJECT);
         return 1;
     }
-    else {
-        line_t templine = {0};
-        templine.len = strlen(result->cld);
-        templine.text = result->cld;
-        if (empty_line(&templine)) {
-            fprintf(stderr, "%s: boxes may not consist entirely of whitespace\n", PROJECT);
-            return 1;
-        }
-    }
     result->design_choice_by_user = 1;
     return 0;
 }
@@ -285,7 +276,7 @@ static int eol_override(opt_t *result, char *optarg)
         result->eol = "\r";
     }
     else {
-        fprintf(stderr, "%s: invalid eol spec -- %s\n", PROJECT, optarg);
+        bx_fprintf(stderr, "%s: invalid eol spec -- %s\n", PROJECT, optarg);
         return 1;
     }
     return 0;
@@ -312,7 +303,7 @@ static int indentation_mode(opt_t *result, char *optarg)
         result->indentmode = 'n';
     }
     else {
-        fprintf(stderr, "%s: invalid indentation mode\n", PROJECT);
+        bx_fprintf(stderr, "%s: invalid indentation mode\n", PROJECT);
         return 1;
     }
     return 0;
@@ -336,7 +327,7 @@ static int killblank(opt_t *result, char *optarg)
             result->killblank = 0;
         }
         else {
-            fprintf(stderr, "%s: -k: invalid parameter\n", PROJECT);
+            bx_fprintf(stderr, "%s: -k: invalid parameter\n", PROJECT);
             return 1;
         }
     }
@@ -353,10 +344,11 @@ static int killblank(opt_t *result, char *optarg)
  */
 static int padding(opt_t *result, char *optarg)
 {
-    int errfl = 0;
+    int errfl = 1;
     char *p = optarg;
 
     while (*p) {
+        errfl = 0;
         if (p[1] == '\0') {
             errfl = 1;
             break;
@@ -404,7 +396,7 @@ static int padding(opt_t *result, char *optarg)
         }
     }
     if (errfl) {
-        fprintf(stderr, "%s: invalid padding specification - %s\n", PROJECT, optarg);
+        bx_fprintf(stderr, "%s: invalid padding specification - %s\n", PROJECT, optarg);
         return 1;
     }
     return 0;
@@ -451,7 +443,7 @@ static int size_of_box(opt_t *result, char *optarg)
         *p = 'x';
     }
     if (errno || (result->reqwidth == 0 && result->reqheight == 0) || result->reqwidth < 0 || result->reqheight < 0) {
-        fprintf(stderr, "%s: invalid box size specification -- %s\n", PROJECT, optarg);
+        bx_fprintf(stderr, "%s: invalid box size specification -- %s\n", PROJECT, optarg);
         return 1;
     }
     return 0;
@@ -470,7 +462,7 @@ static int tab_handling(opt_t *result, char *optarg)
     char *p;
     int width = (int) strtol(optarg, &p, 10);
     if (width < 1 || width > MAX_TABSTOP) {
-        fprintf(stderr, "%s: invalid tab stop distance -- %d\n", PROJECT, width);
+        bx_fprintf(stderr, "%s: invalid tab stop distance -- %d\n", PROJECT, width);
         return 1;
     }
     result->tabstop = width;
@@ -498,7 +490,7 @@ static int tab_handling(opt_t *result, char *optarg)
         }
     }
     if (errfl) {
-        fprintf(stderr, "%s: invalid tab handling specification - %s\n", PROJECT, optarg);
+        bx_fprintf(stderr, "%s: invalid tab handling specification - %s\n", PROJECT, optarg);
         return 1;
     }
     return 0;
@@ -543,7 +535,7 @@ static int input_output_files(opt_t *result, char *argv[], int optind)
     }
 
     else if (argv[optind + 1] && argv[optind + 2]) {         /* illegal third file */
-        fprintf(stderr, "%s: illegal parameter -- %s\n", PROJECT, argv[optind + 2]);
+        bx_fprintf(stderr, "%s: illegal parameter -- %s\n", PROJECT, argv[optind + 2]);
         usage_short(stderr);
         return 1;
     }
@@ -555,7 +547,7 @@ static int input_output_files(opt_t *result, char *argv[], int optind)
         else {
             result->infile = fopen(argv[optind], "r");
             if (result->infile == NULL) {
-                fprintf(stderr, "%s: Can\'t open input file -- %s\n", PROJECT, argv[optind]);
+                bx_fprintf(stderr, "%s: Can\'t open input file -- %s\n", PROJECT, argv[optind]);
                 return 9;                                    /* can't read infile */
             }
         }
@@ -620,7 +612,17 @@ static void print_debug_info(opt_t *result)
 
 opt_t *process_commandline(int argc, char *argv[])
 {
+    #ifdef DEBUG
+        fprintf(stderr, "argc = %d\n", argc);
+        fprintf(stderr, "argv = [");
+        for(int i=0; i<=argc; i++) {
+            fprintf(stderr, "%s%s", argv[i], i < argc ? ", " : "");
+        }
+        fprintf(stderr, "]\n");
+    #endif
+
     opt_t *result = create_new_opt();
+    optind = 1;   /* ensure that getopt() will process all arguments, even in unit test situations */
 
     /* Intercept '--help' and '-?' cases first, as they are not supported by getopt() */
     if (argc >= 2 && argv[1] != NULL && (strcmp(argv[1], "--help") == 0 || strcmp(argv[1], "-?") == 0)) {
@@ -739,7 +741,7 @@ opt_t *process_commandline(int argc, char *argv[])
                 break;
 
             default:
-                fprintf(stderr, "%s: internal error\n", PROJECT);
+                bx_fprintf(stderr, "%s: internal error\n", PROJECT);
                 return NULL;
         }
     } while (oc != EOF);
