@@ -2,20 +2,15 @@
  * boxes - Command line filter to draw/remove ASCII boxes around text
  * Copyright (c) 1999-2021 Thomas Jensen and the boxes contributors
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License, version 2, as published
- * by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
+ * License, version 3, as published by the Free Software Foundation.
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
+ * You should have received a copy of the GNU General Public License along with this program.
+ * If not, see <https://www.gnu.org/licenses/>.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
-* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  */
 
 /*
@@ -201,7 +196,7 @@ int isempty(const sentry_t *shape)
 
 int isdeepempty(const sentry_t *shape)
 /*
- *  Return true if shape is empty, also checking if lines consist of spaces
+ *  Return true if shape is empty, also checking if lines consist of whitespace
  *  only.
  *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -215,7 +210,7 @@ int isdeepempty(const sentry_t *shape)
 
     for (j = 0; j < shape->height; ++j) {
         if (shape->chars[j]) {
-            if (strspn(shape->chars[j], " ") != shape->width) {
+            if (strspn(shape->chars[j], " \t") != shape->width) {
                 return 0;
             }
         }
